ListExtension extension
Extensions on Lists
- on
-
- List?
Properties
- isNotNullNotEmpty → bool
-
Available on List?, provided by the ListExtension extension
if the list Not equal null and contains datano setter - isNullOrEmpty → bool
-
Available on List?, provided by the ListExtension extension
true if list is Null or Empty list false: Null list false: Empty Listno setter