isNullOrEmpty property
bool
get
isNullOrEmpty
true if list is Null or Empty list false: Null list false: Empty List
Implementation
bool get isNullOrEmpty => this == null || this!.isEmpty;
true if list is Null or Empty list false: Null list false: Empty List
bool get isNullOrEmpty => this == null || this!.isEmpty;