bodyLarge property
TextStyle?
get
bodyLarge
The large body text style from the current theme.
Implementation
TextStyle? get bodyLarge => _themeData.textTheme.bodyLarge;
The large body text style from the current theme.
TextStyle? get bodyLarge => _themeData.textTheme.bodyLarge;