bodyMedium property
TextStyle?
get
bodyMedium
The medium body text style from the current theme.
Implementation
TextStyle? get bodyMedium => _themeData.textTheme.bodyMedium;
The medium body text style from the current theme.
TextStyle? get bodyMedium => _themeData.textTheme.bodyMedium;