bodySmall property
TextStyle?
get
bodySmall
The small body text style from the current theme.
Implementation
TextStyle? get bodySmall => _themeData.textTheme.bodySmall;
The small body text style from the current theme.
TextStyle? get bodySmall => _themeData.textTheme.bodySmall;