displaySmall property
TextStyle?
get
displaySmall
The small display text style from the current theme.
Implementation
TextStyle? get displaySmall => _themeData.textTheme.displaySmall;
The small display text style from the current theme.
TextStyle? get displaySmall => _themeData.textTheme.displaySmall;