headlineSmall property
TextStyle?
get
headlineSmall
The small headline text style from the current theme.
Implementation
TextStyle? get headlineSmall => _themeData.textTheme.headlineSmall;
The small headline text style from the current theme.
TextStyle? get headlineSmall => _themeData.textTheme.headlineSmall;