isDesktop property
bool
get
isDesktop
Whether the app is running on a desktop platform.
Implementation
bool get isDesktop =>
Platform.isMacOS || Platform.isLinux || Platform.isWindows;
Whether the app is running on a desktop platform.
bool get isDesktop =>
Platform.isMacOS || Platform.isLinux || Platform.isWindows;