isMobile property
bool
get
isMobile
Whether the app is running on a mobile platform.
Implementation
bool get isMobile => Platform.isIOS || Platform.isAndroid;
Whether the app is running on a mobile platform.
bool get isMobile => Platform.isIOS || Platform.isAndroid;