isTablet property
bool
get
isTablet
Whether the current screen width matches the tablet breakpoint.
Implementation
bool get isTablet => MediaQuery.of(this).size.width >= 600;
Whether the current screen width matches the tablet breakpoint.
bool get isTablet => MediaQuery.of(this).size.width >= 600;