labelMedium property
TextStyle?
get
labelMedium
The medium label text style from the current theme.
Implementation
TextStyle? get labelMedium => _themeData.textTheme.labelMedium;
The medium label text style from the current theme.
TextStyle? get labelMedium => _themeData.textTheme.labelMedium;