labelSmall property
TextStyle?
get
labelSmall
The small label text style from the current theme.
Implementation
TextStyle? get labelSmall => _themeData.textTheme.labelSmall;
The small label text style from the current theme.
TextStyle? get labelSmall => _themeData.textTheme.labelSmall;