titleMedium property
TextStyle?
get
titleMedium
The medium title text style from the current theme.
Implementation
TextStyle? get titleMedium => _themeData.textTheme.titleMedium;
The medium title text style from the current theme.
TextStyle? get titleMedium => _themeData.textTheme.titleMedium;