titleSmall property
TextStyle?
get
titleSmall
The small title text style from the current theme.
Implementation
TextStyle? get titleSmall => _themeData.textTheme.titleSmall;
The small title text style from the current theme.
TextStyle? get titleSmall => _themeData.textTheme.titleSmall;