StringExtensions extension
Helper Method for the String Data Type
- on
Properties
- concatenateAsterisk → String
-
Available on String, provided by the StringExtensions extension
Concatenate Asterisk At The End Of the Stringno setter - concatenateBrackets → String
-
Available on String, provided by the StringExtensions extension
Concatenate Brackets Between Stringno setter - concatenateColon → String
-
Available on String, provided by the StringExtensions extension
Concatenate Colon At The End Of the Stringno setter - concatenateComma → String
-
Available on String, provided by the StringExtensions extension
Concatenate Comma At The End Of the Stringno setter - concatenateDash → String
-
Available on String, provided by the StringExtensions extension
Concatenate Dash At The End Of the Stringno setter - concatenateDollarSign → String
-
Available on String, provided by the StringExtensions extension
Concatenate Dollar Signno setter - concatenateExclamation → String
-
Available on String, provided by the StringExtensions extension
Concatenate Exclamation At The End Of the Stringno setter - concatenateHash → String
-
Available on String, provided by the StringExtensions extension
Concatenate Hash At The End Of the Stringno setter - concatenateNewline → String
-
Available on String, provided by the StringExtensions extension
Concatenate Newline At The End Of the Stringno setter - concatenateQuestionMarkArabic → String
-
Available on String, provided by the StringExtensions extension
Concatenate Question Mark Arabic At Endno setter - concatenateQuestionMarkEnglish → String
-
Available on String, provided by the StringExtensions extension
Concatenate Question Mark English At Endno setter - concatenateSpace → String
-
Available on String, provided by the StringExtensions extension
Concatenate Space At The End Of the Stringno setter - separateNumberWithComma → String
-
Available on String, provided by the StringExtensions extension
no setter
Methods
-
isMediaVideo(
) → bool -
Available on String, provided by the StringExtensions extension
-
takeChars(
int number) → String -
Available on String, provided by the StringExtensions extension
Take the firstnumberof characters from the string Ifnumberis greater than string length, returns the entire string Ifnumberis negative or zero, returns an empty string -
takeWords(
int number) → String -
Available on String, provided by the StringExtensions extension
Take the firstnumberof words from the string Words are separated by whitespace Ifnumberis greater than word count, returns the entire string Ifnumberis negative or zero, returns an empty string -
toArabicDigitsConverter(
) → String -
Available on String, provided by the StringExtensions extension
Static Properties
- numberFormat → NumberFormat
-
Available on String, provided by the StringExtensions extension
final
Constants
-
arabicDigits
→ const Map<
String, String> -
Convert the latin digits to Arabic ones
arabicDigits
"0"'0': '\u0660', '1': '\u0661', '2': '\u0662', '3': '\u0663', '4': '\u0664', '5': '\u0665', '6': '\u0666', '7': '\u0667', '8': '\u0668', '9': '\u0669',