displayLarge property
TextStyle?
get
displayLarge
Display styles are the largest text styles in the theme. Use them for short, prominent text such as hero headlines.
Implementation
TextStyle? get displayLarge => _themeData.textTheme.displayLarge;